@@ -9,7 +9,7 @@ use CGI::Application::Plugin::Session;
 sub cgiapp_init {
   my $self = shift;
 
-  $self->session_config(CGI_SESSION_OPTIONS => [ "driver:File", $self->query, {Directory=>'t/'} ]);
+  $self->session_config(CGI_SESSION_OPTIONS => [ "driver:File", $self->query ]);
 }
 
 sub setup {
