@@ -10,7 +10,7 @@ sub cgiapp_init {
   my $self = shift;
 
   $self->session_config({
-                        CGI_SESSION_OPTIONS => [ "driver:File", $self->query, {Directory=>'t/'} ],
+                        CGI_SESSION_OPTIONS => [ "driver:File", $self->query ],
                         SEND_COOKIE         => 1,
                         DEFAULT_EXPIRY      => '+1h',
                         COOKIE_PARAMS       => {
@@ -47,7 +47,6 @@ sub logout {
   if ( ! $query->cookie( 'CGISESSID' ) ) {
       return "didn't get session passed in!";
   } else {
-      my $session = $self->session;
       $self->session_delete;
       return "logout finished";
   }
